pygeodesy.deprecated.classes

Package pygeodesy :: Package deprecated :: Module classes |
[frames] | no frames]

# Module classes

DEPRECATED classes kept for backward compatibility.

Version: 25.11.11

Classes
| _Deprecated_NamedTuple DEPRECATED, `_NamedTuple` base.
| ClipCS3Tuple DEPRECATED, see DEPRECATED function pygeodesy.deprecated.clipCS3.
| EasNorExact4Tuple DEPRECATED, use class Forward4Tuple, item `gamma` for `convergence`.
| JacobiConformal DEPRECATED on 2025.10.25, use class Conformal.
| JacobiConformalSpherical DEPRECATED on 2025.10.25, use class ConformalSphere.
| Jacobi2Tuple DEPRECATED on 25.11.11, use class Conformal2Tuple.
| Lam_ DEPRECATED on 2024.06.15, use class Lamd.
| LatLonExact4Tuple DEPRECATED, use class Reverse4Tuple, item `gamma` for `convergence`.
| NearestOn4Tuple DEPRECATED on 2023.10.10, see methods RhumbLine.nearestOn4 and RhumbLineAux.nearestOn4.
| Phi_ DEPRECATED on 2024.06.15, use class Phid.
| Ned3Tuple DEPRECATED, use class Ned4Tuple, ignoring item `ltp`.
| Rhumb7Tuple DEPRECATED, use class Rhumb8Tuple, ignoring item `a12`.
| RhumbOrder2Tuple DEPRECATED, see deprecated method Rhumb.orders.
| Transform7Tuple DEPRECATED on 2024.02.02, use class TRFXform7Tuple, without keyword arguments.
| Helmert7Tuple DEPRECATED on 2024.02.02, use class TRFXform7Tuple, without keyword arguments.
| TriAngle4Tuple DEPRECATED on 2023.09.14, use class TriAngle5Tuple, ignoring item `area`.
| UtmUps4Tuple DEPRECATED and OBSOLETE, expect a UtmUps5Tuple from method `pygeodesy.Mgrs.toUtm(utm=None)`.
| XDist DEPRECATED on 2024.07.02, use class ADict.

Functions
EcefCartesian(*args, **kwds) DEPRECATED, use class LocalCartesian. |
Fn_rt(root, *xs, **name_RESIDUAL_raiser) DEPRECATED on 2024.04.17, use class Froot. |
FrechetCosineAndoyerLambert(point1s, **kwds) DEPRECATED on 2024.12.31, use class FrechetCosineLaw with `corr=1`. |
FrechetCosineForsytheAndoyerLambert(point1s, **kwds) DEPRECATED on 2024.12.31, use class FrechetCosineLaw with `corr=2`. |
HausdorffCosineAndoyerLambert(point1s, **kwds) DEPRECATED on 2024.12.31, use class HausdorffCosineLaw with `corr=1`. |
HausdorffCosineForsytheAndoyerLambert(point1s, **kwds) DEPRECATED on 2024.12.31, use class HausdorffCosineLaw with `corr=2`. |
HeightIDW(knots, **kwds) DEPRECATED, use class HeightIDWeuclidean. |
HeightIDW2(knots, **kwds) DEPRECATED, use class HeightIDWequirectangular. |
HeightIDW3(knots, **kwds) DEPRECATED, use class HeightIDWhaversine. |
HeightIDWcosineAndoyerLambert(knots, **kwds) DEPRECATED on 2024.12.31, use class HeightIDWcosineLaw with `corr=1`. |
HeightIDWcosineForsytheAndoyerLambert(knots, **kwds) DEPRECATED on 2024.12.31, use class HeightIDWcosineLaw with `corr=2`. |
RefFrameError(*args, **kwds) DEPRECATED, use class TRFError. |

Variables
| __all__ = `_ALL_DEPRECATED.deprecated_classes`